<a id="mypy-boto3-xray"></a>

# mypy-boto3-xray

[![PyPI - types-aiobotocore-xray](https://img.shields.io/pypi/v/types-aiobotocore-xray.svg?color=blue)](https://pypi.org/project/types-aiobotocore-xray)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-xray.svg?color=blue)](https://pypi.org/project/types-aiobotocore-xray)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-xray?color=blue)](https://pypistats.org/packages/types-aiobotocore-xray)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.XRay 1.20.47](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/xray.html#XRay)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.4.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[types-aiobotocore-xray docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_xray/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-xray](#mypy-boto3-xray)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `XRay`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `XRay` service.

```bash
# install with aiobotocore type annotations
python -m pip install 'types-aiobotocore[xray]'

# Lite version does not provide session.create_client overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'types-aiobotocore-lite[xray]'

# standalone installation
python -m pip install types-aiobotocore-xray
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[xray]` in your environment:
  `python -m pip install 'types-aiobotocore[xray]'`

Both type checking and auto-complete should work for `XRay` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `types-aiobotocore[xray]` in your environment:
  `python -m pip install 'types-aiobotocore[xray]'`

Both type checking and auto-complete should work for `XRay` service. No
explicit type annotations required, write your `aiobotocore` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`types-aiobotocore` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[xray]` in your environment:
  `python -m pip install 'types-aiobotocore[xray]'`
- Run `mypy` as usual

Type checking should work for `XRay` service. No explicit type annotations
required, write your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `types-aiobotocore[xray]` in your environment:
  `python -m pip install 'types-aiobotocore[xray]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `XRay` service. No explicit type annotations
required, write your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`XRayClient` provides annotations for `session.create_client("xray")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_xray import XRayClient

session = get_session()
async with session.create_client("xray") as client:
    client: XRayClient
    # now client usage is checked by mypy and IDE should provide code auto-complete
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_xray.paginator` module contains type annotations for all
paginators.

````python
from aiobotocore.session import get_session

from types_aiobotocore_xray import XRayClient
from types_aiobotocore_xray.paginator import (
    BatchGetTracesPaginator,
    GetGroupsPaginator,
    GetSamplingRulesPaginator,
    GetSamplingStatisticSummariesPaginator,
    GetServiceGraphPaginator,
    GetTimeSeriesServiceStatisticsPaginator,
    GetTraceGraphPaginator,
    GetTraceSummariesPaginator,
)

session = get_session()
async with session.create_client("xray") as client:
    client: XRayClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        batch_get_traces_paginator: BatchGetTracesPaginator = client.get_paginator("batch_get_traces")
        get_groups_paginator: GetGroupsPaginator = client.get_paginator("get_groups")
        get_sampling_rules_paginator: GetSamplingRulesPaginator = client.get_paginator("get_sampling_rules")
        get_sampling_statistic_summaries_paginator: GetSamplingStatisticSummariesPaginator = client.get_paginator("get_sampling_statistic_summaries")
        get_service_graph_paginator: GetServiceGraphPaginator = client.get_paginator("get_service_graph")
        get_time_series_service_statistics_paginator: GetTimeSeriesServiceStatisticsPaginator = client.get_paginator("get_time_series_service_statistics")
        get_trace_graph_paginator: GetTraceGraphPaginator = client.get_paginator("get_trace_graph")
        get_trace_summaries_paginator: GetTraceSummariesPaginator = client.get_paginator("get_trace_summaries")
    ```







### Literals

`types_aiobotocore_xray.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_xray.literals import (
    BatchGetTracesPaginatorName,
    EncryptionStatusType,
    EncryptionTypeType,
    GetGroupsPaginatorName,
    GetSamplingRulesPaginatorName,
    GetSamplingStatisticSummariesPaginatorName,
    GetServiceGraphPaginatorName,
    GetTimeSeriesServiceStatisticsPaginatorName,
    GetTraceGraphPaginatorName,
    GetTraceSummariesPaginatorName,
    InsightCategoryType,
    InsightStateType,
    SamplingStrategyNameType,
    TimeRangeTypeType,
    ServiceName,
    PaginatorName,
)

def check_value(value: BatchGetTracesPaginatorName) -> bool:
    ...
````

### Typed dictionaries

`types_aiobotocore_xray.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_xray.type_defs import (
    AliasTypeDef,
    AnnotationValueTypeDef,
    AnomalousServiceTypeDef,
    AvailabilityZoneDetailTypeDef,
    BackendConnectionErrorsTypeDef,
    BatchGetTracesRequestRequestTypeDef,
    BatchGetTracesResultTypeDef,
    CreateGroupRequestRequestTypeDef,
    CreateGroupResultTypeDef,
    CreateSamplingRuleRequestRequestTypeDef,
    CreateSamplingRuleResultTypeDef,
    DeleteGroupRequestRequestTypeDef,
    DeleteSamplingRuleRequestRequestTypeDef,
    DeleteSamplingRuleResultTypeDef,
    EdgeStatisticsTypeDef,
    EdgeTypeDef,
    EncryptionConfigTypeDef,
    ErrorRootCauseEntityTypeDef,
    ErrorRootCauseServiceTypeDef,
    ErrorRootCauseTypeDef,
    ErrorStatisticsTypeDef,
    FaultRootCauseEntityTypeDef,
    FaultRootCauseServiceTypeDef,
    FaultRootCauseTypeDef,
    FaultStatisticsTypeDef,
    ForecastStatisticsTypeDef,
    GetEncryptionConfigResultTypeDef,
    GetGroupRequestRequestTypeDef,
    GetGroupResultTypeDef,
    GetGroupsRequestRequestTypeDef,
    GetGroupsResultTypeDef,
    GetInsightEventsRequestRequestTypeDef,
    GetInsightEventsResultTypeDef,
    GetInsightImpactGraphRequestRequestTypeDef,
    GetInsightImpactGraphResultTypeDef,
    GetInsightRequestRequestTypeDef,
    GetInsightResultTypeDef,
    GetInsightSummariesRequestRequestTypeDef,
    GetInsightSummariesResultTypeDef,
    GetSamplingRulesRequestRequestTypeDef,
    GetSamplingRulesResultTypeDef,
    GetSamplingStatisticSummariesRequestRequestTypeDef,
    GetSamplingStatisticSummariesResultTypeDef,
    GetSamplingTargetsRequestRequestTypeDef,
    GetSamplingTargetsResultTypeDef,
    GetServiceGraphRequestRequestTypeDef,
    GetServiceGraphResultTypeDef,
    GetTimeSeriesServiceStatisticsRequestRequestTypeDef,
    GetTimeSeriesServiceStatisticsResultTypeDef,
    GetTraceGraphRequestRequestTypeDef,
    GetTraceGraphResultTypeDef,
    GetTraceSummariesRequestRequestTypeDef,
    GetTraceSummariesResultTypeDef,
    GroupSummaryTypeDef,
    GroupTypeDef,
    HistogramEntryTypeDef,
    HttpTypeDef,
    InsightEventTypeDef,
    InsightImpactGraphEdgeTypeDef,
    InsightImpactGraphServiceTypeDef,
    InsightSummaryTypeDef,
    InsightTypeDef,
    InsightsConfigurationTypeDef,
    InstanceIdDetailTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    PaginatorConfigTypeDef,
    PutEncryptionConfigRequestRequestTypeDef,
    PutEncryptionConfigResultTypeDef,
    PutTelemetryRecordsRequestRequestTypeDef,
    PutTraceSegmentsRequestRequestTypeDef,
    PutTraceSegmentsResultTypeDef,
    RequestImpactStatisticsTypeDef,
    ResourceARNDetailTypeDef,
    ResponseMetadataTypeDef,
    ResponseTimeRootCauseEntityTypeDef,
    ResponseTimeRootCauseServiceTypeDef,
    ResponseTimeRootCauseTypeDef,
    RootCauseExceptionTypeDef,
    SamplingRuleRecordTypeDef,
    SamplingRuleTypeDef,
    SamplingRuleUpdateTypeDef,
    SamplingStatisticSummaryTypeDef,
    SamplingStatisticsDocumentTypeDef,
    SamplingStrategyTypeDef,
    SamplingTargetDocumentTypeDef,
    SegmentTypeDef,
    ServiceIdTypeDef,
    ServiceStatisticsTypeDef,
    ServiceTypeDef,
    TagResourceRequestRequestTypeDef,
    TagTypeDef,
    TelemetryRecordTypeDef,
    TimeSeriesServiceStatisticsTypeDef,
    TraceSummaryTypeDef,
    TraceTypeDef,
    TraceUserTypeDef,
    UnprocessedStatisticsTypeDef,
    UnprocessedTraceSegmentTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateGroupRequestRequestTypeDef,
    UpdateGroupResultTypeDef,
    UpdateSamplingRuleRequestRequestTypeDef,
    UpdateSamplingRuleResultTypeDef,
    ValueWithServiceIdsTypeDef,
)

def get_structure() -> AliasTypeDef:
    return {
      ...
    }
```

## Versioning

`types-aiobotocore-xray` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Documentation

All type annotations can be found in
[types-aiobotocore-xray docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_xray/)

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
